==> easyapi-0.7.6.1-sources.jar: cn/easyutil/easyapi/entity/db/doc/DBModuleHeaderEntity.java <==
package cn.easyutil.easyapi.entity.db.doc;

import cn.easyutil.easyapi.datasource.annotations.Tfd;
import cn.easyutil.easyapi.datasource.annotations.Tne;
import cn.easyutil.easyapi.entity.common.ApidocComment;

/**
 * 模块全局header头
 */
@Tne("EASYAPI_MODULE_HEADER")
public class DBModuleHeaderEntity extends BaseDbEntity {

    @Tfd(value = "MODULE_ID",ddl = "`MODULE_ID` bigint(20) DEFAULT NULL COMMENT '模块id'")
    @ApidocComment("模块id")
    private Long moduleId;

    @Tfd(value = "USER_ID",ddl = "`USER_ID` bigint(20) DEFAULT NULL COMMENT '用户id'")
    @ApidocComment("用户id")
    private Long userId;

    @Tfd(value = "TYPE",ddl = "`TYPE` int(1) DEFAULT 0 COMMENT '类型  0-私有 1-共有'")
    @ApidocComment("类型  0-私有 1-共有")
    private Integer type;

    @Tfd(value = "NAME",ddl = "`NAME` varchar(50) DEFAULT NULL COMMENT '名称'")
    @ApidocComment("header名称")
    private String name;

    @Tfd(value = "KEY",ddl = "`KEY` varchar(100) DEFAULT NULL COMMENT 'key'")
    @ApidocComment("key")
    private String key;

    @Tfd(value = "VAL",ddl = "`VAL` varchar(255) DEFAULT NULL COMMENT 'val'")
    @ApidocComment("val")
    private String val;

    public Long getModuleId() {
        return moduleId;
    }

    public void setModuleId(Long moduleId) {
        this.moduleId = moduleId;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getKey() {
        return key;
    }

    public void setKey(String key) {
        this.key = key;
    }

    public String getVal() {
        return val;
    }

    public void setVal(String val) {
        this.val = val;
    }

    public Long getUserId() {
        return userId;
    }

    public void setUserId(Long userId) {
        this.userId = userId;
    }

    public Integer getType() {
        return type;
    }

    public void setType(Integer type) {
        this.type = type;
    }
}

==> easyapi-0.8.3-sources.jar: cn/easyutil/easyapi/entity/db/doc/DBModuleHeaderEntity.java <==
package cn.easyutil.easyapi.entity.db.doc;

import cn.easyutil.easyapi.entity.annotation.DDL;
import cn.easyutil.easyapi.entity.common.ApidocComment;
import com.baomidou.mybatisplus.annotation.TableName;

/**
 * 模块全局header头
 */
@TableName("EASYAPI_MODULE_HEADER")
public class DBModuleHeaderEntity extends BaseDbEntity {

    @DDL(value = "MODULE_ID",ddl = "`MODULE_ID` bigint(20) DEFAULT NULL COMMENT '模块id'")
    @ApidocComment("模块id")
    private Long moduleId;

    @DDL(value = "USER_ID",ddl = "`USER_ID` bigint(20) DEFAULT NULL COMMENT '用户id'")
    @ApidocComment("用户id")
    private Long userId;

    @DDL(value = "TYPE",ddl = "`TYPE` int(1) DEFAULT 0 COMMENT '类型  0-私有 1-共有'")
    @ApidocComment("类型  0-私有 1-共有")
    private Integer type;

    @DDL(value = "NAME",ddl = "`NAME` varchar(50) DEFAULT NULL COMMENT '名称'")
    @ApidocComment("header名称")
    private String name;

    @DDL(value = "KEY",ddl = "`KEY` varchar(100) DEFAULT NULL COMMENT 'key'")
    @ApidocComment("key")
    private String key;

    @DDL(value = "VAL",ddl = "`VAL` varchar(255) DEFAULT NULL COMMENT 'val'")
    @ApidocComment("val")
    private String val;

    public Long getModuleId() {
        return moduleId;
    }

    public void setModuleId(Long moduleId) {
        this.moduleId = moduleId;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getKey() {
        return key;
    }

    public void setKey(String key) {
        this.key = key;
    }

    public String getVal() {
        return val;
    }

    public void setVal(String val) {
        this.val = val;
    }

    public Long getUserId() {
        return userId;
    }

    public void setUserId(Long userId) {
        this.userId = userId;
    }

    public Integer getType() {
        return type;
    }

    public void setType(Integer type) {
        this.type = type;
    }
}
